Description Usage Format Details Source Examples
Meteorological data from automated weather stations in Mexico
1 | data("weather_mx")
|
A data frame with 395403 observations on the following 16 variables.
USAFStation number
YYear
MMonth
DDay
Mean.tempMean temperature [C]
Min.tempMinimum temperature[C]
Max.tempMaximum temperature[C]
DewpointMean dew point [C]
Relative.HRelative humidity [%]
Specific.HSpecific humidity
PressureMean air pressure [hPa]
PrecipitationTotal precipitation
VisibilityVisibility for the day [m]
Wind.speedMean wind speed [m/s]
Max.WSMaximum sustained wind speed (1 min) [m/s]
Wind.gustMaximum wind gust
This dataset contains automated weather station data from the National Oceanic and Atmospheric Administration (NOAA).
Data provided by National Oceanic and Atmospheric Administration (NOAA). ftp://ftp.ncdc.noaa.gov/pub/data/noaa/isd-history.txt
1 2 | data(weather_mx)
## maybe str(weather_mx) ; plot(weather_mx) ...
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.